---
name: Feature request
about: Request a new API or feature implementation
title: ''
labels: 'new feature/request :speech_balloon:'
assignees: ''

---

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. What kind of performance improvements would you like to see with this new API?
